==> ejc-prjfinance-impl-3.0.1-20210727.084140-38-sources.jar: com/ejianc/business/prjfinance/bean/ProjectDutyLetterEntity.java <==
package com.ejianc.business.prjfinance.bean;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * <p>
 * 项目目标责任书
 * </p>
 *
 * @author liyj
 * @since 2021-07-19
 */
@TableName("ejc_prjfinance_dutyletter")
public class ProjectDutyLetterEntity extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /**
     * 单据状态
     */
    @TableField("bill_state")
    private Integer billState;

    /**
     * 项目id
     */
    @TableField("project_id")
    private Long projectId;

    /**
     * 项目名称
     */
    @TableField("project_name")
    private String projectName;

    /**
     * 项目部id
     */
    @TableField("project_department_id")
    private Long projectDepartmentId;

    /**
     * 项目部名称（冗余）
     */
    @TableField("project_department_name")
    private String projectDepartmentName;

    /**
     * 责任书名称
     */
    @TableField("duty_letter_name")
    private String dutyLetterName;

    /**
     * 单据编码
     */
    @TableField("bill_code")
    private String billCode;

    /**
     * 责任书状态(1:未签订,2:履约中,3:已封账)
     */
    @TableField("duty_letter_state")
    private String dutyLetterState;

    /**
     * 经济责任人
     */
    @TableField("economic_person_id")
    private Long economicPersonId;

    /**
     * 经济责任人
     */
    @TableField("economic_person_name")
    private String economicPersonName;

	/**
	 * 签约日期
	 */
	@TableField(value = "signing_date", fill = FieldFill.INSERT)
	@JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date signingDate;
	
    /**
     * 管理费比例
     */
    @TableField("management_expense")
    private BigDecimal managementExpense;
	
    /**
     * 争议违约处理方式
     */
    @TableField("dispute_breach_contract_dealway")
    private Long disputeBreachContractDealway;

    /**
     * 施工合同金额
     */
    @TableField("construction_contract_amount")
    private BigDecimal constructionContractAmount;

    /**
     * 风险保证金收取方式: onetime:一次性收取固定金额,bymonth:按月收取金额,bybeceived按已收工程款比例
     */
    @TableField("risk_margin_collection_method")
    private String riskMarginCollectionMethod;

    /**
     * 单次扣除比例
     */
    @TableField("single_deduction_ratio")
    private BigDecimal singleDeductionRatio;

    /**
     * 风险保证金额
     */
    @TableField("risk_guarantee_amount")
    private BigDecimal riskGuaranteeAmount;

	/**
	 * 计划开工日期
	 */
	@TableField(value = "planned_commencement_date", fill = FieldFill.INSERT)
	@JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date plannedCommencementDate;

	/**
	 * 计划竣工日期
	 */
	@TableField(value = "planned_finish_date", fill = FieldFill.INSERT)
	@JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date plannedFinishDate;

    /**
     * 合同工期
     */
    @TableField("contract_duration")
    private Integer contractDuration;

    /**
     * 经办人
     */
    @TableField("operator")
    private Long operator;

    /**
     * 施工合同质量目标
     */
    @TableField("construction_contract_quality_target")
    private String constructionContractQualityTarget;

    /**
     * 安全文明施工标化目标
     */
    @TableField("safe_civilized_construction_standard_target")
    private String safeCivilizedConstructionStandardTarget;

    /**
     * 质量环境安全管理要求
     */
    @TableField("quality_safety_management_requirement")
    private String qualitySafetyManagementRequirement;

    /**
     * 科技创新目标
     */
    @TableField("technological_innovation_target")
    private String technologicalInnovationTarget;

    /**
     * 奖励与处罚
     */
    @TableField("reward_and_punishment")
    private String rewardAndPunishment;

    /**
     * 财务管理说明
     */
    @TableField("financial_management_description")
    private String financialManagementDescription;

    /**
     * 备注
     */
    @TableField("remarks")
    private String remarks;

    /**
     * 变更版本号
     */
    @TableField("change_version")
    private Integer changeVersion;

    /**
     * 变更状态（"0":"未签订","1":"履约中","2":"未签订"）
     */
    @TableField("change_state")
    private String changeState;

    /**
     * 变更中的编号
     */
    @TableField("change_code")
    private String changeCode;

    /**
     * 变更原因
     */
    @TableField("change_reason")
    private String changeReason;

    /**
     * 变更单id
     */
    @TableField("change_id")
    private Long changeId;

    /**
     * 子表
     */
    @TableField(exist = false)
    @SubEntity(serviceName = "projectDutyLetterCostlistService", pidName="dutyLetterId")
    private List<ProjectDutyLetterCostlistEntity> projectDutyLetterCostList = new ArrayList<>();

    /**
     * 子表
     */
    @TableField(exist = false)
    @SubEntity(serviceName = "projectDutyLetterClauseService", pidName="dutyLetterId")
    private List<ProjectDutyLetterClauseEntity> projectDutyLetterClauseList = new ArrayList<>();

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getDutyLetterName() {
		return dutyLetterName;
	}

	public void setDutyLetterName(String dutyLetterName) {
		this.dutyLetterName = dutyLetterName;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public Long getEconomicPersonId() {
		return economicPersonId;
	}

	public void setEconomicPersonId(Long economicPersonId) {
		this.economicPersonId = economicPersonId;
	}

	public String getEconomicPersonName() {
		return economicPersonName;
	}

	public void setEconomicPersonName(String economicPersonName) {
		this.economicPersonName = economicPersonName;
	}

	public Date getSigningDate() {
		return signingDate;
	}

	public void setSigningDate(Date signingDate) {
		this.signingDate = signingDate;
	}

	public Long getDisputeBreachContractDealway() {
		return disputeBreachContractDealway;
	}

	public void setDisputeBreachContractDealway(Long disputeBreachContractDealway) {
		this.disputeBreachContractDealway = disputeBreachContractDealway;
	}

	public String getRiskMarginCollectionMethod() {
		return riskMarginCollectionMethod;
	}

	public void setRiskMarginCollectionMethod(String riskMarginCollectionMethod) {
		this.riskMarginCollectionMethod = riskMarginCollectionMethod;
	}

	public BigDecimal getSingleDeductionRatio() {
		return singleDeductionRatio;
	}

	public void setSingleDeductionRatio(BigDecimal singleDeductionRatio) {
		this.singleDeductionRatio = singleDeductionRatio;
	}

	public BigDecimal getRiskGuaranteeAmount() {
		return riskGuaranteeAmount;
	}

	public void setRiskGuaranteeAmount(BigDecimal riskGuaranteeAmount) {
		this.riskGuaranteeAmount = riskGuaranteeAmount;
	}

	public Date getPlannedCommencementDate() {
		return plannedCommencementDate;
	}

	public void setPlannedCommencementDate(Date plannedCommencementDate) {
		this.plannedCommencementDate = plannedCommencementDate;
	}

	public Date getPlannedFinishDate() {
		return plannedFinishDate;
	}

	public void setPlannedFinishDate(Date plannedFinishDate) {
		this.plannedFinishDate = plannedFinishDate;
	}

	public Integer getContractDuration() {
		return contractDuration;
	}

	public void setContractDuration(Integer contractDuration) {
		this.contractDuration = contractDuration;
	}

	public Long getOperator() {
		return operator;
	}

	public void setOperator(Long operator) {
		this.operator = operator;
	}

	public String getConstructionContractQualityTarget() {
		return constructionContractQualityTarget;
	}

	public void setConstructionContractQualityTarget(String constructionContractQualityTarget) {
		this.constructionContractQualityTarget = constructionContractQualityTarget;
	}

	public String getSafeCivilizedConstructionStandardTarget() {
		return safeCivilizedConstructionStandardTarget;
	}

	public void setSafeCivilizedConstructionStandardTarget(String safeCivilizedConstructionStandardTarget) {
		this.safeCivilizedConstructionStandardTarget = safeCivilizedConstructionStandardTarget;
	}

	public String getQualitySafetyManagementRequirement() {
		return qualitySafetyManagementRequirement;
	}

	public void setQualitySafetyManagementRequirement(String qualitySafetyManagementRequirement) {
		this.qualitySafetyManagementRequirement = qualitySafetyManagementRequirement;
	}

	public String getTechnologicalInnovationTarget() {
		return technologicalInnovationTarget;
	}

	public void setTechnologicalInnovationTarget(String technologicalInnovationTarget) {
		this.technologicalInnovationTarget = technologicalInnovationTarget;
	}

	public String getRewardAndPunishment() {
		return rewardAndPunishment;
	}

	public void setRewardAndPunishment(String rewardAndPunishment) {
		this.rewardAndPunishment = rewardAndPunishment;
	}

	public String getFinancialManagementDescription() {
		return financialManagementDescription;
	}

	public void setFinancialManagementDescription(String financialManagementDescription) {
		this.financialManagementDescription = financialManagementDescription;
	}

	public String getRemarks() {
		return remarks;
	}

	public void setRemarks(String remarks) {
		this.remarks = remarks;
	}

	public List<ProjectDutyLetterCostlistEntity> getProjectDutyLetterCostList() {
		return projectDutyLetterCostList;
	}

	public void setProjectDutyLetterCostList(List<ProjectDutyLetterCostlistEntity> projectDutyLetterCostList) {
		this.projectDutyLetterCostList = projectDutyLetterCostList;
	}

	public List<ProjectDutyLetterClauseEntity> getProjectDutyLetterClauseList() {
		return projectDutyLetterClauseList;
	}

	public void setProjectDutyLetterClauseList(List<ProjectDutyLetterClauseEntity> projectDutyLetterClauseList) {
		this.projectDutyLetterClauseList = projectDutyLetterClauseList;
	}

	public BigDecimal getConstructionContractAmount() {
		return constructionContractAmount;
	}

	public void setConstructionContractAmount(BigDecimal constructionContractAmount) {
		this.constructionContractAmount = constructionContractAmount;
	}

	public BigDecimal getManagementExpense() {
		return managementExpense;
	}

	public void setManagementExpense(BigDecimal managementExpense) {
		this.managementExpense = managementExpense;
	}

	public String getDutyLetterState() {
		return dutyLetterState;
	}

	public void setDutyLetterState(String dutyLetterState) {
		this.dutyLetterState = dutyLetterState;
	}

	public Long getProjectDepartmentId() {
		return projectDepartmentId;
	}

	public void setProjectDepartmentId(Long projectDepartmentId) {
		this.projectDepartmentId = projectDepartmentId;
	}

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public Integer getChangeVersion() {
		return changeVersion;
	}

	public void setChangeVersion(Integer changeVersion) {
		this.changeVersion = changeVersion;
	}

	public String getChangeState() {
		return changeState;
	}

	public void setChangeState(String changeState) {
		this.changeState = changeState;
	}

	public String getProjectDepartmentName() {
		return projectDepartmentName;
	}

	public void setProjectDepartmentName(String projectDepartmentName) {
		this.projectDepartmentName = projectDepartmentName;
	}

	public String getChangeCode() {
		return changeCode;
	}

	public void setChangeCode(String changeCode) {
		this.changeCode = changeCode;
	}

	public String getChangeReason() {
		return changeReason;
	}

	public void setChangeReason(String changeReason) {
		this.changeReason = changeReason;
	}

	public Long getChangeId() {
		return changeId;
	}

	public void setChangeId(Long changeId) {
		this.changeId = changeId;
	}

}

==> ejc-prjfinance-impl-3.0.1-20250821.083608-159-sources.jar: com/ejianc/business/prjfinance/bean/ProjectDutyLetterEntity.java <==
package com.ejianc.business.prjfinance.bean;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import com.baomidou.mybatisplus.annotation.FieldFill;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * <p>
 * 项目目标责任书
 * </p>
 *
 * @author liyj
 * @since 2021-07-19
 */
@TableName("ejc_prjfinance_dutyletter")
public class ProjectDutyLetterEntity extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /**
     * 单据状态
     */
    @TableField("bill_state")
    private Integer billState;

    /**
     * 项目id
     */
    @TableField("project_id")
    private Long projectId;

    /**
     * 项目名称
     */
    @TableField("project_name")
    private String projectName;

    /**
     * 项目部id
     */
    @TableField("project_department_id")
    private Long projectDepartmentId;

    /**
     * 项目部名称（冗余）
     */
    @TableField("project_department_name")
    private String projectDepartmentName;

    /**
     * 责任书名称
     */
    @TableField("duty_letter_name")
    private String dutyLetterName;

    /**
     * 单据编码
     */
    @TableField("bill_code")
    private String billCode;

    /**
     * 责任书状态(1:未签订,2:履约中,3:已封账)
     */
    @TableField("duty_letter_state")
    private String dutyLetterState;

    /**
     * 经济责任人
     */
    @TableField("economic_person_id")
    private Long economicPersonId;

    /**
     * 经济责任人
     */
    @TableField("economic_person_name")
    private String economicPersonName;

	/**
	 * 签约日期
	 */
	@TableField(value = "signing_date", fill = FieldFill.INSERT)
	@JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date signingDate;
	
    /**
     * 管理费比例
     */
    @TableField("management_expense")
    private BigDecimal managementExpense;
	
    /**
     * 争议违约处理方式
     */
    @TableField("dispute_breach_contract_dealway")
    private Long disputeBreachContractDealway;

    /**
     * 施工合同金额
     */
    @TableField("construction_contract_amount")
    private BigDecimal constructionContractAmount;

    /**
     * 风险保证金收取方式: onetime:一次性收取固定金额,bymonth:按月收取金额,bybeceived按已收工程款比例
     */
    @TableField("risk_margin_collection_method")
    private String riskMarginCollectionMethod;

    /**
     * 单次扣除比例
     */
    @TableField("single_deduction_ratio")
    private BigDecimal singleDeductionRatio;

    /**
     * 风险保证金额
     */
    @TableField("risk_guarantee_amount")
    private BigDecimal riskGuaranteeAmount;

	/**
	 * 计划开工日期
	 */
	@TableField(value = "planned_commencement_date", fill = FieldFill.INSERT)
	@JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date plannedCommencementDate;

	/**
	 * 计划竣工日期
	 */
	@TableField(value = "planned_finish_date", fill = FieldFill.INSERT)
	@JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
	private Date plannedFinishDate;

    /**
     * 合同工期
     */
    @TableField("contract_duration")
    private Integer contractDuration;

    @TableField("management_receive_type")
    private Integer managementReceiveType;

    /**
     * 经办人
     */
    @TableField("operator")
    private Long operator;

    /**
     * 施工合同质量目标
     */
    @TableField("construction_contract_quality_target")
    private String constructionContractQualityTarget;

    /**
     * 安全文明施工标化目标
     */
    @TableField("safe_civilized_construction_standard_target")
    private String safeCivilizedConstructionStandardTarget;

    /**
     * 质量环境安全管理要求
     */
    @TableField("quality_safety_management_requirement")
    private String qualitySafetyManagementRequirement;

    /**
     * 科技创新目标
     */
    @TableField("technological_innovation_target")
    private String technologicalInnovationTarget;

    /**
     * 奖励与处罚
     */
    @TableField("reward_and_punishment")
    private String rewardAndPunishment;

    /**
     * 财务管理说明
     */
    @TableField("financial_management_description")
    private String financialManagementDescription;

    /**
     * 备注
     */
    @TableField("remarks")
    private String remarks;

    /**
     * 变更版本号
     */
    @TableField("change_version")
    private Integer changeVersion;

    /**
     * 变更状态（"0":"未签订","1":"履约中","2":"未签订"）
     */
    @TableField("change_state")
    private String changeState;

    /**
     * 变更中的编号
     */
    @TableField("change_code")
    private String changeCode;

    /**
     * 变更原因
     */
    @TableField("change_reason")
    private String changeReason;

    /**
     * 变更单id
     */
    @TableField("change_id")
    private Long changeId;

    /**
     * 子表
     */
    @TableField(exist = false)
    @SubEntity(serviceName = "projectDutyLetterCostlistService", pidName="dutyLetterId")
    private List<ProjectDutyLetterCostlistEntity> projectDutyLetterCostList = new ArrayList<>();

    /**
     * 子表
     */
    @TableField(exist = false)
    @SubEntity(serviceName = "projectDutyLetterClauseService", pidName="dutyLetterId")
    private List<ProjectDutyLetterClauseEntity> projectDutyLetterClauseList = new ArrayList<>();

	public Long getProjectId() {
		return projectId;
	}

	public void setProjectId(Long projectId) {
		this.projectId = projectId;
	}

	public String getProjectName() {
		return projectName;
	}

	public void setProjectName(String projectName) {
		this.projectName = projectName;
	}

	public String getDutyLetterName() {
		return dutyLetterName;
	}

	public void setDutyLetterName(String dutyLetterName) {
		this.dutyLetterName = dutyLetterName;
	}

	public String getBillCode() {
		return billCode;
	}

	public void setBillCode(String billCode) {
		this.billCode = billCode;
	}

	public Long getEconomicPersonId() {
		return economicPersonId;
	}

	public void setEconomicPersonId(Long economicPersonId) {
		this.economicPersonId = economicPersonId;
	}

	public String getEconomicPersonName() {
		return economicPersonName;
	}

	public void setEconomicPersonName(String economicPersonName) {
		this.economicPersonName = economicPersonName;
	}

	public Date getSigningDate() {
		return signingDate;
	}

	public void setSigningDate(Date signingDate) {
		this.signingDate = signingDate;
	}

	public Long getDisputeBreachContractDealway() {
		return disputeBreachContractDealway;
	}

	public void setDisputeBreachContractDealway(Long disputeBreachContractDealway) {
		this.disputeBreachContractDealway = disputeBreachContractDealway;
	}

	public String getRiskMarginCollectionMethod() {
		return riskMarginCollectionMethod;
	}

	public Integer getManagementReceiveType() {
		return managementReceiveType;
	}

	public void setManagementReceiveType(Integer managementReceiveType) {
		this.managementReceiveType = managementReceiveType;
	}

	public void setRiskMarginCollectionMethod(String riskMarginCollectionMethod) {
		this.riskMarginCollectionMethod = riskMarginCollectionMethod;
	}

	public BigDecimal getSingleDeductionRatio() {
		return singleDeductionRatio;
	}

	public void setSingleDeductionRatio(BigDecimal singleDeductionRatio) {
		this.singleDeductionRatio = singleDeductionRatio;
	}

	public BigDecimal getRiskGuaranteeAmount() {
		return riskGuaranteeAmount;
	}

	public void setRiskGuaranteeAmount(BigDecimal riskGuaranteeAmount) {
		this.riskGuaranteeAmount = riskGuaranteeAmount;
	}

	public Date getPlannedCommencementDate() {
		return plannedCommencementDate;
	}

	public void setPlannedCommencementDate(Date plannedCommencementDate) {
		this.plannedCommencementDate = plannedCommencementDate;
	}

	public Date getPlannedFinishDate() {
		return plannedFinishDate;
	}

	public void setPlannedFinishDate(Date plannedFinishDate) {
		this.plannedFinishDate = plannedFinishDate;
	}

	public Integer getContractDuration() {
		return contractDuration;
	}

	public void setContractDuration(Integer contractDuration) {
		this.contractDuration = contractDuration;
	}

	public Long getOperator() {
		return operator;
	}

	public void setOperator(Long operator) {
		this.operator = operator;
	}

	public String getConstructionContractQualityTarget() {
		return constructionContractQualityTarget;
	}

	public void setConstructionContractQualityTarget(String constructionContractQualityTarget) {
		this.constructionContractQualityTarget = constructionContractQualityTarget;
	}

	public String getSafeCivilizedConstructionStandardTarget() {
		return safeCivilizedConstructionStandardTarget;
	}

	public void setSafeCivilizedConstructionStandardTarget(String safeCivilizedConstructionStandardTarget) {
		this.safeCivilizedConstructionStandardTarget = safeCivilizedConstructionStandardTarget;
	}

	public String getQualitySafetyManagementRequirement() {
		return qualitySafetyManagementRequirement;
	}

	public void setQualitySafetyManagementRequirement(String qualitySafetyManagementRequirement) {
		this.qualitySafetyManagementRequirement = qualitySafetyManagementRequirement;
	}

	public String getTechnologicalInnovationTarget() {
		return technologicalInnovationTarget;
	}

	public void setTechnologicalInnovationTarget(String technologicalInnovationTarget) {
		this.technologicalInnovationTarget = technologicalInnovationTarget;
	}

	public String getRewardAndPunishment() {
		return rewardAndPunishment;
	}

	public void setRewardAndPunishment(String rewardAndPunishment) {
		this.rewardAndPunishment = rewardAndPunishment;
	}

	public String getFinancialManagementDescription() {
		return financialManagementDescription;
	}

	public void setFinancialManagementDescription(String financialManagementDescription) {
		this.financialManagementDescription = financialManagementDescription;
	}

	public String getRemarks() {
		return remarks;
	}

	public void setRemarks(String remarks) {
		this.remarks = remarks;
	}

	public List<ProjectDutyLetterCostlistEntity> getProjectDutyLetterCostList() {
		return projectDutyLetterCostList;
	}

	public void setProjectDutyLetterCostList(List<ProjectDutyLetterCostlistEntity> projectDutyLetterCostList) {
		this.projectDutyLetterCostList = projectDutyLetterCostList;
	}

	public List<ProjectDutyLetterClauseEntity> getProjectDutyLetterClauseList() {
		return projectDutyLetterClauseList;
	}

	public void setProjectDutyLetterClauseList(List<ProjectDutyLetterClauseEntity> projectDutyLetterClauseList) {
		this.projectDutyLetterClauseList = projectDutyLetterClauseList;
	}

	public BigDecimal getConstructionContractAmount() {
		return constructionContractAmount;
	}

	public void setConstructionContractAmount(BigDecimal constructionContractAmount) {
		this.constructionContractAmount = constructionContractAmount;
	}

	public BigDecimal getManagementExpense() {
		return managementExpense;
	}

	public void setManagementExpense(BigDecimal managementExpense) {
		this.managementExpense = managementExpense;
	}

	public String getDutyLetterState() {
		return dutyLetterState;
	}

	public void setDutyLetterState(String dutyLetterState) {
		this.dutyLetterState = dutyLetterState;
	}

	public Long getProjectDepartmentId() {
		return projectDepartmentId;
	}

	public void setProjectDepartmentId(Long projectDepartmentId) {
		this.projectDepartmentId = projectDepartmentId;
	}

	public Integer getBillState() {
		return billState;
	}

	public void setBillState(Integer billState) {
		this.billState = billState;
	}

	public Integer getChangeVersion() {
		return changeVersion;
	}

	public void setChangeVersion(Integer changeVersion) {
		this.changeVersion = changeVersion;
	}

	public String getChangeState() {
		return changeState;
	}

	public void setChangeState(String changeState) {
		this.changeState = changeState;
	}

	public String getProjectDepartmentName() {
		return projectDepartmentName;
	}

	public void setProjectDepartmentName(String projectDepartmentName) {
		this.projectDepartmentName = projectDepartmentName;
	}

	public String getChangeCode() {
		return changeCode;
	}

	public void setChangeCode(String changeCode) {
		this.changeCode = changeCode;
	}

	public String getChangeReason() {
		return changeReason;
	}

	public void setChangeReason(String changeReason) {
		this.changeReason = changeReason;
	}

	public Long getChangeId() {
		return changeId;
	}

	public void setChangeId(Long changeId) {
		this.changeId = changeId;
	}

}
